import animation
from typing import List, Literal

from extractor.g_section import GSection
from extractor.input_data import InputData
from extractor.main import load_control_kinematics, load_features, calculate_gdi


def load(source_frames: str, side: Literal['L'] | Literal['R']) -> InputData:
    left, right = animation.split_animation(source_frames)

    def resolve_side():
        return left if side == 'L' else right

    def resolve_name(gdi: GSection):
        return resolve_side()[gdi.get_full_column_name(side)]

    return InputData(
        side,
        pelvisAnglesX=resolve_name(GSection.PELVIS_ANGLES_X),
        pelvisAnglesY=resolve_name(GSection.PELVIS_ANGLES_Y),
        pelvisAnglesZ=resolve_name(GSection.PELVIS_ANGLES_Z),
        hipAnglesX=resolve_name(GSection.HIP_ANGLES_X),
        hipAnglesY=resolve_name(GSection.HIP_ANGLES_Y),
        hipAnglesZ=resolve_name(GSection.HIP_ANGLES_Z),
        kneeAnglesX=resolve_name(GSection.KNEE_ANGLES_X),
        ankleAnglesX=resolve_name(GSection.ANKLE_ANGLES_X),
        footProgressAnglesZ=resolve_name(GSection.FOOT_PROGRESS_ANGLES_Z)
    )


def load_g(source_frames: str, side: Literal['L'] | Literal['R']) -> List[float]:
    input_data = load(source_frames, side)
    reduced_g = input_data.get_g()
    return reduced_g


def extract_gdi(source_frames: str) -> float:
    control_kinematics = load_control_kinematics()
    features = load_features()

    g = load_g(source_frames, 'L')
    gdi_result_left = calculate_gdi(control_kinematics, features, g)

    g = load_g(source_frames, 'R')
    gdi_result_right = calculate_gdi(control_kinematics, features, g)

    gdi_result = min(gdi_result_left, gdi_result_right)
    return round(gdi_result, 5)
