"""CSV Utils

This script helps to load CSV files to numpy array

This tool accepts (.csv) files.

This script requires that `numpy` be installed within the Python
environment you are running this script in.

This file can also be imported as a module and contains the following
functions:

    * load - returns numpy array from the CSV file
"""
import numpy as np


def _conv(value):
    """Converts the string value with decimal delimiter ',' decimal delimiter to '.'

    Parameters
    ----------
    value : str
        An original value

    Returns
    -------
    out : str
        Converted value
    """
    return value.replace(',', '.').encode()


def load(filename: str):
    """Loads data from the CSV file with delimiter ; and skip header.

    Parameters
    ----------
    filename : str
        A filename to load

    Returns
    -------
    out : np.ndarray
        List of values loaded from the file
    """
    with open(filename) as file:
        return np.genfromtxt((_conv(x) for x in file), delimiter=';', skip_header=1)
