"""Matrix Formatter

This script contains util for formatting big matrix in Jupyter

This file can also be imported as a module and contains the following
functions:

    * to_string - returns the formatted matrix
"""


def to_string(matrix: list):
    """Converts numpy matrix for better readability in Jupyter.

    Parameters
    ----------
    matrix : ndarray
        A numpy matrix

    Returns
    -------
    out: str
        Formatted matrix
    """
    s = [[str(e) for e in row] for row in matrix]
    lens = [max(map(len, col)) for col in zip(*s)]
    fmt = '\t'.join('{{:{}}}'.format(x) for x in lens)
    table = [fmt.format(*row) for row in s]
    return '\n'.join(table)
