from __future__ import annotations

from enum import Enum, auto


class GSection(str, Enum):
    """
    A class holds metadata how to parse data from the input file,
    order them in g list and access them in the InputData class.
    """
    # The order of the columns in g list
    order: int
    # The column name which contains g section values in the input file - without side as a prefix
    input_column: str
    # Lambda function to get values from the input data (input_data.py)
    list_provider: auto()

    def __new__(
            cls, title: str, order: int = 99, list_provider: None = None
    ) -> GSection:
        obj = str.__new__(cls, title)
        obj._value_ = title

        obj.order = order
        obj.input_column = title
        obj.list_provider = list_provider
        return obj

    def get_full_column_name(self, side: str = ''):
        if side != 'R' and side != 'L':
            raise Exception(f'Cannot create full column name. The side can be "R" or "L". Got: {side}')

        return side + self.input_column

    PELVIS_ANGLES_X = ('PelvisAngles_x', 1, lambda a: a.pelvisAnglesX)
    PELVIS_ANGLES_Y = ('PelvisAngles_y', 2, lambda a: a.pelvisAnglesY)
    PELVIS_ANGLES_Z = ('PelvisAngles_z', 3, lambda a: a.pelvisAnglesZ)
    HIP_ANGLES_X = ('HipAngles_x', 4, lambda a: a.hipAnglesX)
    HIP_ANGLES_Y = ('HipAngles_y', 5, lambda a: a.hipAnglesY)
    HIP_ANGLES_Z = ('HipAngles_z', 6, lambda a: a.hipAnglesZ)
    KNEE_ANGLES_X = ('KneeAngles_x', 7, lambda a: a.kneeAnglesX)
    ANKLE_ANGLES_X = ('AnkleAngles_x', 8, lambda a: a.ankleAnglesX)
    FOOT_PROGRESS_ANGLES_Z = ('FootProgressAngles_z', 9, lambda a: a.footProgressAnglesZ)
