import math

from .g_section import GSection


class InputData:
    """
    A class used to hold required columns from the input file
    """
    side = 'unknown'
    pelvisAnglesX = []
    pelvisAnglesY = []
    pelvisAnglesZ = []
    hipAnglesX = []
    hipAnglesY = []
    hipAnglesZ = []
    kneeAnglesX = []
    ankleAnglesX = []
    footProgressAnglesZ = []

    def __init__(self, side, pelvisAnglesX, pelvisAnglesY, pelvisAnglesZ, hipAnglesX, hipAnglesY, hipAnglesZ,
                 kneeAnglesX, ankleAnglesX, footProgressAnglesZ):
        self.side = side
        self.pelvisAnglesY = pelvisAnglesY
        self.pelvisAnglesZ = pelvisAnglesZ
        self.pelvisAnglesX = pelvisAnglesX
        self.hipAnglesX = hipAnglesX
        self.hipAnglesY = hipAnglesY
        self.hipAnglesZ = hipAnglesZ
        self.kneeAnglesX = kneeAnglesX
        self.ankleAnglesX = ankleAnglesX
        self.footProgressAnglesZ = footProgressAnglesZ

    def get_g(self):
        """Provides ordered and reduced list of values that were loaded from input file

        Raises
        ------
        Exception
            If the final length of the array is not 459 or any value in the columns is not a number

        Returns
        -------
        list
            The float values - The same values what are needed in g.csv
        """
        g = []
        for item in sorted(GSection, key=lambda gdi_enum: gdi_enum.order):
            reduced_values = item.list_provider(self)[::2]
            for value in reduced_values:
                if math.isnan(value):
                    raise Exception(f'The value in column "{item.input_column}" is not number. The value "{value}"')

            g.extend(item.list_provider(self)[::2])

        if len(g) != 459:
            raise Exception("The subject CSV file must contain 459 values in one column")

        return g
