import sys
from pathlib import Path
sys.path.append(str(Path(__file__).parent.parent))

import algorithm
import server_utils


def prepare_output(quality: float) -> str:
    output_object = '#objectKey messif.objects.keys.AbstractObjectKey unspecified\n'
    output_object += str(quality)
    return output_object


def handle_connection(conn, addr):
    try:
        object_size: int = server_utils.read_payload_size(conn)
        input_object: str = server_utils.read_object(conn, object_size)

        gdi: float = algorithm.extract_gdi(input_object)

        output_object: str = prepare_output(gdi)
        print(f"Gait Deviation Index extracted (gdi: {gdi}), addr: {addr})")

    except Exception as ex:
        print(f"[Error] (message: {ex}, addr: {addr})")
        output_object: str = server_utils.prepare_error(str(ex))

    conn.sendall(bytes(output_object, "utf-8"))


class Server(server_utils.Server):
    def start(self, *, host: str, port: int):
        super().start(host=host, port=port)


server = Server(handle_connection)
if __name__ == '__main__':
    server.start(host='0.0.0.0', port=65434)
